@@ -1,6 +1,8 @@
 #define QT_FEATURE_ffmpeg 1
 
-#define QT_FEATURE_pipewire -1
+#define QT_FEATURE_pipewire 1
+
+#define QT_FEATURE_pipewire_screencapture 1
 
 #define QT_FEATURE_alsa -1
 
@@ -10,8 +12,6 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_evr -1
-
 #define QT_FEATURE_gstreamer -1
 
 #define QT_FEATURE_gstreamer_photography -1
@@ -34,7 +34,9 @@
 
 #define QT_FEATURE_mmrenderer -1
 
-#define QT_FEATURE_pulseaudio -1
+#define QT_FEATURE_native_android_backend -1
+
+#define QT_FEATURE_pulseaudio 1
 
 #define QT_FEATURE_wmsdk -1
 
